MODEL_DICT = {
    # Gemini Models
    "Gemini 2.0 Flash": "gemini/gemini-2.0-flash",
    "Gemini 2.0 Flash Lite": "gemini/gemini-2.0-flash-lite",
    "Gemini 2.5 Flash": "gemini/gemini-2.5-flash",
    "Gemini 2.5 Flash Preview": "gemini/gemini-2.5-flash-preview-05-20",
    "Gemini 2.5 Flash Lite Preview": "gemini/gemini-2.5-flash-lite-preview-06-17",

    # OpenAI Models
    "GPT-4o Mini": "openai/gpt-4o-mini",
    "GPT-4o": "openai/gpt-4o",
    "GPT-4.1": "openai/gpt-4.1",
    "GPT-4.1 Mini": "openai/gpt-4.1-mini",
    "GPT-4.1 Nano": "openai/gpt-4.1-nano",

    # Anthropic Models
    "Claude Sonnet 4": "anthropic/claude-sonnet-4",
    "Claude 3.7 Sonnet": "anthropic/claude-3.7-sonnet",
    "Claude 3.5 Sonnet": "anthropic/claude-3.5-sonnet",

    # Openrouter (free)
    "Deepseek Chat (Free)": "openrouter/deepseek/deepseek-chat:free",
    "Qwen3 32B (Free)": "openrouter/qwen/qwen3-32b:free",
    "Mistral Small 3.1 Instruct (Free)": "openrouter/mistralai/mistral-small-3.1-24b-instruct:free",
    "Mistral Small 3.2 Instruct (Free)": "openrouter/mistralai/mistral-small-3.2-24b-instruct:free",
    "Devstral Small (Free)": "openrouter/mistralai/devstral-small:free",
    "Qwen3 14B (Free)": "openrouter/qwen/qwen3-14b:free",
    "Qwen3 8B (Free)": "openrouter/qwen/qwen3-8b:free",
    "Gemma-3 27B IT (Free)": "openrouter/google/gemma-3-27b-it:free",
} 

