from setuptools import setup, find_packages
import os

# Read the contents of your README file
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Package version
VERSION = "1.0.1"

setup(
    name="tai-textual",
    version=VERSION,
    author="Shoaib",
    author_email="shoaib8@gmail.com>",
    description="tAI is a tool that helps you to find the right command.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    package_data={
        "tAI": ["config.json", ".env","secret.key","App/style.tcss"],
    },
    install_requires=[
        "aiohappyeyeballs==2.6.1",
        "aiohttp==3.12.13",
        "aiosignal==1.3.2",
        "annotated-types==0.7.0",
        "anyio==4.9.0",
        "attrs==25.3.0",
        "cachetools==5.5.2",
        "certifi==2025.1.31",
        "cffi==1.17.1",
        "charset-normalizer==3.4.2",
        "click==8.2.1",
        "cryptography==45.0.5",
        "distro==1.9.0",
        "docutils==0.21.2",
        "evdev==1.9.2",
        "filelock==3.18.0",
        "frozenlist==1.7.0",
        "fsspec==2025.5.1",
        "google-auth==2.40.2",
        "google-genai==1.17.0",
        "h11==0.14.0",
        "hf-xet==1.1.5",
        "httpcore==1.0.8",
        "httpx==0.28.1",
        "huggingface-hub==0.33.1",
        "id==1.5.0",
        "idna==3.10",
        "importlib_metadata==8.7.0",
        "jaraco.classes==3.4.0",
        "jaraco.context==6.0.1",
        "jaraco.functools==4.2.1",
        "jeepney==0.9.0",
        "Jinja2==3.1.6",
        "jiter==0.10.0",
        "jsonschema==4.24.0",
        "jsonschema-specifications==2025.4.1",
        "keyring==25.6.0",
        "linkify-it-py==2.0.3",
        "litellm==1.73.1",
        "markdown-it-py==3.0.0",
        "MarkupSafe==3.0.2",
        "mdit-py-plugins==0.4.2",
        "mdurl==0.1.2",
        "more-itertools==10.7.0",
        "multidict==6.5.1",
        "nh3==0.2.21",
        "openai==1.91.0",
        "ordered-set==4.1.0",
        "packaging==25.0",
        "platformdirs==4.3.7",
        "prompt_toolkit==3.0.51",
        "propcache==0.3.2",
        "pyasn1==0.6.1",
        "pyasn1_modules==0.4.2",
        "pycparser==2.22",
        "pydantic==2.11.5",
        "pydantic_core==2.33.2",
        "Pygments==2.19.1",
        "pynput==1.8.1",
        "python-dotenv==1.1.0",
        "python-xlib==0.33",
        "PyYAML==6.0.2",
        "readme_renderer==44.0",
        "referencing==0.36.2",
        "regex==2024.11.6",
        "requests==2.32.3",
        "requests-toolbelt==1.0.0",
        "rfc3986==2.0.0",
        "rich==14.0.0",
        "rpds-py==0.25.1",
        "rsa==4.9.1",
        "SecretStorage==3.3.3",
        "setuptools==80.9.0",
        "six==1.17.0",
        "sniffio==1.3.1",
        "textual==3.1.0",
        "tiktoken==0.9.0",
        "tokenizers==0.21.2",
        "tqdm==4.67.1",
        "twine==6.1.0",
        "typing-inspection==0.4.1",
        "typing_extensions==4.13.2",
        "uc-micro-py==1.0.3",
        "urllib3==2.4.0",
        "wcwidth==0.2.13",
        "websockets==15.0.1",
        "wheel==0.45.1",
        "yarl==1.20.1",
        "zipp==3.23.0",
        "zstandard==0.23.0",
    ],
    entry_points={
        "console_scripts": [
            "tai=tAI:tAI",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Terminals",
        "Topic :: Utilities",
    ],
    python_requires='>=3.12',
    project_urls={
        "Bug Tracker": "https://github.com/KillerShoaib/tAI/issues",
        "Source Code": "https://github.com/KillerShoaib/tAI",
    },
) 